@@ -14,13 +14,13 @@ import os
 import re
 import sys
 from copy import copy
-from sphinx.util import logging
+import sphinx.util
 from sphinxcontrib.mat_lexer import MatlabLexer
 from pygments.token import Token
 from zipfile import ZipFile
 import xml.etree.ElementTree as ET
 
-logger = logging.getLogger('matlab-domain')
+logger = sphinx.util.logging.getLogger('matlab-domain')
 
 modules = {}
 
@@ -822,19 +822,58 @@ class MatClass(MatMixin, MatObject):
                     attr_dict, idx = self.attributes(idx, MatClass.prop_attr_types)
                     # Token.Keyword: "end" terminates properties & methods block
                     while self._tk_ne(idx, (Token.Keyword, 'end')):
-                        # skip comments and whitespace
-                        while (self._whitespace(idx) or
-                               self.tokens[idx][0] is Token.Comment):
+                        # skip whitespace
+                        while self._whitespace(idx):
                             whitespace = self._whitespace(idx)
                             if whitespace:
                                 idx += whitespace
                             else:
                                 idx += 1
-                        # TODO: alternate multiline docstring before property
+                                
+                        # =========================================================
+                        # long docstring before property
+                        if self.tokens[idx][0] is Token.Comment:
+                            # docstring
+                            docstring = ''
+                            
+                            # Collect comment lines
+                            while self.tokens[idx][0] is Token.Comment:
+                                docstring += self.tokens[idx][1].lstrip('%')
+                                idx += 1 
+                                idx += self._blanks(idx)
+                                
+                                try:
+                                    # Check if end of line was reached
+                                    if self.tokens[idx][0] == Token.Text and self.tokens[idx][1] == '\n':
+                                        docstring += '\n'
+                                        idx += 1
+                                        idx += self._blanks(idx)
+                                        
+                                    # Check if variable name is next                                        
+                                    if self.tokens[idx][0] is Token.Name:
+                                        prop_name = self.tokens[idx][1]
+                                        self.properties[prop_name] = {'attrs': attr_dict}
+                                        self.properties[prop_name]['docstring'] = docstring
+                                        break
+                                    
+                                    # If there is an empty line at the end of 
+                                    # the comment: discard it
+                                    elif self.tokens[idx][0] == Token.Text and self.tokens[idx][1] == '\n':
+                                        docstring = ''
+                                        idx += self._whitespace(idx)
+                                        break
+                                    
+                                except IndexError:
+                                    # EOF reached, quit gracefully
+                                    break    
+                            
                         # with "%:" directive trumps docstring after property
                         if self.tokens[idx][0] is Token.Name:
                             prop_name = self.tokens[idx][1]
-                            self.properties[prop_name] = {'attrs': attr_dict}
+                            idx += 1
+                            # Initialize property if it was not already done
+                            if not prop_name in self.properties.keys():
+                                self.properties[prop_name] = {'attrs': attr_dict}
 
                             # skip size, class and functions specifiers
                             # TODO: Parse old and new style property extras
@@ -851,6 +890,10 @@ class MatClass(MatMixin, MatObject):
                                   self.tokens[idx][0] == Token.Name or \
                                   self.tokens[idx][0] == Token.Text:
                                 idx += 1
+                                
+                            if self._tk_eq(idx, (Token.Punctuation, ';')):
+                                continue
+                            
                         # subtype of Name EG Name.Builtin used as Name
                         elif self.tokens[idx][0] in Token.Name.subtypes:  # @UndefinedVariable
                             prop_name = self.tokens[idx][1]
@@ -865,7 +908,22 @@ class MatClass(MatMixin, MatObject):
                         # skip semicolon after property name, but no default
                         elif self._tk_eq(idx, (Token.Punctuation, ';')):
                             idx += 1
-                            continue
+                            # A comment might come after semi-colon
+                            idx += self._blanks(idx)
+                            if self._tk_eq(idx, (Token.Text, '\n')):
+                                idx += 1
+                                # Property definition is finished; add missing values
+                                if 'default' not in self.properties[prop_name].keys():
+                                    self.properties[prop_name]['default'] = None
+                                if 'docstring' not in self.properties[prop_name].keys():
+                                    self.properties[prop_name]['docstring'] = None
+                                                                         
+                                continue
+                            elif self.tokens[idx][0] is Token.Comment:
+                                docstring = self.tokens[idx][1].lstrip('%')
+                                docstring += '\n'
+                                self.properties[prop_name]['docstring'] = docstring
+                                idx += 1
                         else:
                             msg = '[sphinxcontrib-matlabdomain] Expected property - got %s' % str(self.tokens[idx])
                             logger.warning(msg)
@@ -919,12 +977,17 @@ class MatClass(MatMixin, MatObject):
                         self.properties[prop_name].update(default)
                         # =========================================================
                         # docstring
-                        docstring = {'docstring': None}
-                        if self.tokens[idx][0] is Token.Comment:
-                            docstring['docstring'] = \
-                                self.tokens[idx][1].lstrip('%')
+                        if 'docstring' not in self.properties[prop_name].keys():
+                            docstring = {'docstring': None}
+                            if self.tokens[idx][0] is Token.Comment:
+                                docstring['docstring'] = \
+                                    self.tokens[idx][1].lstrip('%')
+                                idx += 1
+                            self.properties[prop_name].update(docstring)
+                        elif self.tokens[idx][0] is Token.Comment:
+                            # skip this comment
                             idx += 1
-                        self.properties[prop_name].update(docstring)
+                                
                         idx += self._whitespace(idx)
                     idx += 1
                 # =================================================================
